@@ -7,7 +7,7 @@ use Mock::Inflate::Name;
 table {
     name 'mock_inflate';
     pk 'id';
-    columns qw/ id name /;
+    columns qw/ id name foo /;
     inflate 'name' => sub {
         my ($col_value) = @_;
         return Mock::Inflate::Name->new(name => $col_value);
@@ -16,6 +16,14 @@ table {
         my ($col_value) = @_;
         return ref $col_value ? $col_value->name : $col_value . '_deflate';
     };
+    inflate qr/.+oo/ => sub {
+        my ($col_value) = @_;
+        return Mock::Inflate::Name->new(name => $col_value);
+    };
+    deflate qr/.+oo/ => sub {
+        my ($col_value) = @_;
+        return ref $col_value ? $col_value->name : $col_value . '_deflate';
+    };
 };
 
 1;
